===
fwd
===


.. image:: https://img.shields.io/pypi/v/fwd.svg
        :target: https://pypi.python.org/pypi/fwd

.. image:: https://readthedocs.org/projects/fwd/badge/?version=latest
        :target: https://fwd.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




fwd: forwad


* Free software: GNU General Public License v3
* Documentation: https://fwd.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `cogsys-io/cogsys-io-cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _`cogsys-io/cogsys-io-cookiecutter-pypackage`: https://github.com/cogsys-io/cogsys-io-cookiecutter-pypackage
